/* avatar-details-interface.c generated by valac 0.24.0.111-cb21a, the Vala compiler
 * generated from avatar-details-interface.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks.h>
#include <folks-test.h>
#include <gee.h>
#include <gio/gio.h>
#include <folks/folks-tracker.h>


#define TYPE_AVATAR_DETAILS_INTERFACE_TESTS (avatar_details_interface_tests_get_type ())
#define AVATAR_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AVATAR_DETAILS_INTERFACE_TESTS, AvatarDetailsInterfaceTests))
#define AVATAR_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AVATAR_DETAILS_INTERFACE_TESTS, AvatarDetailsInterfaceTestsClass))
#define IS_AVATAR_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AVATAR_DETAILS_INTERFACE_TESTS))
#define IS_AVATAR_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AVATAR_DETAILS_INTERFACE_TESTS))
#define AVATAR_DETAILS_INTERFACE_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AVATAR_DETAILS_INTERFACE_TESTS, AvatarDetailsInterfaceTestsClass))

typedef struct _AvatarDetailsInterfaceTests AvatarDetailsInterfaceTests;
typedef struct _AvatarDetailsInterfaceTestsClass AvatarDetailsInterfaceTestsClass;
typedef struct _AvatarDetailsInterfaceTestsPrivate AvatarDetailsInterfaceTestsPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _AvatarDetailsInterfaceTestsTestAvatarDetailsInterfaceAsyncData AvatarDetailsInterfaceTestsTestAvatarDetailsInterfaceAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _AvatarDetailsInterfaceTests {
	TrackerTestTestCase parent_instance;
	AvatarDetailsInterfaceTestsPrivate * priv;
};

struct _AvatarDetailsInterfaceTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _AvatarDetailsInterfaceTestsPrivate {
	gchar* _avatar_uri;
	gboolean _avatars_are_equal;
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
};

struct _AvatarDetailsInterfaceTestsTestAvatarDetailsInterfaceAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	AvatarDetailsInterfaceTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer avatar_details_interface_tests_parent_class = NULL;

GType avatar_details_interface_tests_get_type (void) G_GNUC_CONST;
#define AVATAR_DETAILS_INTERFACE_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_AVATAR_DETAILS_INTERFACE_TESTS, AvatarDetailsInterfaceTestsPrivate))
enum  {
	AVATAR_DETAILS_INTERFACE_TESTS_DUMMY_PROPERTY
};
AvatarDetailsInterfaceTests* avatar_details_interface_tests_new (void);
AvatarDetailsInterfaceTests* avatar_details_interface_tests_construct (GType object_type);
void avatar_details_interface_tests_test_avatar_details_interface (AvatarDetailsInterfaceTests* self);
static void _avatar_details_interface_tests_test_avatar_details_interface_folks_test_case_test_method (gpointer self);
static void avatar_details_interface_tests_test_avatar_details_interface_async (AvatarDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void avatar_details_interface_tests_test_avatar_details_interface_finish (AvatarDetailsInterfaceTests* self, GAsyncResult* _res_);
static void avatar_details_interface_tests_test_avatar_details_interface_async_data_free (gpointer _data);
static gboolean avatar_details_interface_tests_test_avatar_details_interface_async_co (AvatarDetailsInterfaceTestsTestAvatarDetailsInterfaceAsyncData* _data_);
static void avatar_details_interface_tests_test_avatar_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _avatar_details_interface_tests_individuals_changed_cb (AvatarDetailsInterfaceTests* self, GeeMultiMap* changes);
static void __avatar_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _avatar_details_interface_tests_notify_avatar_cb (AvatarDetailsInterfaceTests* self, GObject* individual_obj, GParamSpec* ps);
static void __avatar_details_interface_tests_notify_avatar_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void avatar_details_interface_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _avatar_details_interface_tests_test_avatar_details_interface_folks_test_case_test_method (gpointer self) {
#line 37 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	avatar_details_interface_tests_test_avatar_details_interface ((AvatarDetailsInterfaceTests*) self);
#line 115 "avatar-details-interface.c"
}


AvatarDetailsInterfaceTests* avatar_details_interface_tests_construct (GType object_type) {
	AvatarDetailsInterfaceTests * self = NULL;
#line 35 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	self = (AvatarDetailsInterfaceTests*) tracker_test_test_case_construct (object_type, "AvatarDetailsInterfaceTests");
#line 37 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test avatar details interface", _avatar_details_interface_tests_test_avatar_details_interface_folks_test_case_test_method, self);
#line 33 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	return self;
#line 127 "avatar-details-interface.c"
}


AvatarDetailsInterfaceTests* avatar_details_interface_tests_new (void) {
#line 33 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	return avatar_details_interface_tests_construct (TYPE_AVATAR_DETAILS_INTERFACE_TESTS);
#line 134 "avatar-details-interface.c"
}


void avatar_details_interface_tests_test_avatar_details_interface (AvatarDetailsInterfaceTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	gchar* avatar_path = NULL;
	gchar* _tmp2_ = NULL;
	GFile* temp_file = NULL;
	GFile* _tmp3_ = NULL;
	gchar* full_avatar_path = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	TrackerTestBackend* _tmp7_ = NULL;
	TrackerTestBackend* _tmp8_ = NULL;
	GMainLoop* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
#line 41 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 43 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 43 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 43 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	self->priv->_main_loop = _tmp0_;
#line 44 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 44 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	c1 = _tmp1_;
#line 45 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp2_ = folks_test_utils_get_source_test_data ("data/avatar-01.jpg");
#line 45 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	avatar_path = _tmp2_;
#line 47 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp3_ = g_file_new_for_path (avatar_path);
#line 47 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	temp_file = _tmp3_;
#line 48 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp4_ = g_file_get_path (temp_file);
#line 48 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	full_avatar_path = _tmp4_;
#line 49 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp5_ = g_strconcat ("file://", full_avatar_path, NULL);
#line 49 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_free0 (self->priv->_avatar_uri);
#line 49 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	self->priv->_avatar_uri = _tmp5_;
#line 50 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	self->priv->_avatars_are_equal = FALSE;
#line 52 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, "persona #1");
#line 53 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp6_ = self->priv->_avatar_uri;
#line 53 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_PHOTO, _tmp6_);
#line 54 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp7_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 54 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c1);
#line 55 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp8_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 55 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 57 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	avatar_details_interface_tests_test_avatar_details_interface_async (self, NULL, NULL);
#line 59 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp9_ = self->priv->_main_loop;
#line 59 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	folks_test_utils_loop_run_with_timeout (_tmp9_, 5);
#line 60 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp10_ = self->priv->_avatars_are_equal;
#line 60 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_vala_assert (_tmp10_, "this._avatars_are_equal");
#line 41 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_free0 (full_avatar_path);
#line 41 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_object_unref0 (temp_file);
#line 41 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_free0 (avatar_path);
#line 41 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_object_unref0 (c1);
#line 218 "avatar-details-interface.c"
}


static void avatar_details_interface_tests_test_avatar_details_interface_async_data_free (gpointer _data) {
	AvatarDetailsInterfaceTestsTestAvatarDetailsInterfaceAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	g_slice_free (AvatarDetailsInterfaceTestsTestAvatarDetailsInterfaceAsyncData, _data_);
#line 229 "avatar-details-interface.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	return self ? g_object_ref (self) : NULL;
#line 236 "avatar-details-interface.c"
}


static void avatar_details_interface_tests_test_avatar_details_interface_async (AvatarDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	AvatarDetailsInterfaceTestsTestAvatarDetailsInterfaceAsyncData* _data_;
	AvatarDetailsInterfaceTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_ = g_slice_new0 (AvatarDetailsInterfaceTestsTestAvatarDetailsInterfaceAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, avatar_details_interface_tests_test_avatar_details_interface_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, avatar_details_interface_tests_test_avatar_details_interface_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	avatar_details_interface_tests_test_avatar_details_interface_async_co (_data_);
#line 255 "avatar-details-interface.c"
}


static void avatar_details_interface_tests_test_avatar_details_interface_finish (AvatarDetailsInterfaceTests* self, GAsyncResult* _res_) {
	AvatarDetailsInterfaceTestsTestAvatarDetailsInterfaceAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 263 "avatar-details-interface.c"
}


static void avatar_details_interface_tests_test_avatar_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	AvatarDetailsInterfaceTestsTestAvatarDetailsInterfaceAsyncData* _data_;
#line 66 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_ = _user_data_;
#line 66 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_->_source_object_ = source_object;
#line 66 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_->_res_ = _res_;
#line 66 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	avatar_details_interface_tests_test_avatar_details_interface_async_co (_data_);
#line 277 "avatar-details-interface.c"
}


static void __avatar_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 70 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_avatar_details_interface_tests_individuals_changed_cb ((AvatarDetailsInterfaceTests*) self, changes);
#line 284 "avatar-details-interface.c"
}


static gboolean avatar_details_interface_tests_test_avatar_details_interface_async_co (AvatarDetailsInterfaceTestsTestAvatarDetailsInterfaceAsyncData* _data_) {
#line 63 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	switch (_data_->_state_) {
#line 63 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		case 0:
#line 293 "avatar-details-interface.c"
		goto _state_0;
#line 63 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		case 1:
#line 297 "avatar-details-interface.c"
		goto _state_1;
#line 63 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		case 2:
#line 301 "avatar-details-interface.c"
		goto _state_2;
		default:
#line 63 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		g_assert_not_reached ();
#line 306 "avatar-details-interface.c"
	}
	_state_0:
#line 65 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_->_tmp0_ = NULL;
#line 65 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 65 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_->store = _data_->_tmp0_;
#line 66 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_->_state_ = 1;
#line 66 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	folks_backend_store_prepare (_data_->store, avatar_details_interface_tests_test_avatar_details_interface_async_ready, _data_);
#line 66 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	return FALSE;
#line 321 "avatar-details-interface.c"
	_state_1:
#line 66 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 69 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_->_tmp1_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 69 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 69 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 70 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_->_tmp2_ = NULL;
#line 70 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 70 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __avatar_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 339 "avatar-details-interface.c"
	{
#line 74 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_data_->_tmp3_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 74 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_data_->_state_ = 2;
#line 74 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, avatar_details_interface_tests_test_avatar_details_interface_async_ready, _data_);
#line 74 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		return FALSE;
#line 351 "avatar-details-interface.c"
		_state_2:
#line 74 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 74 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 357 "avatar-details-interface.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 72 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_data_->e = _data_->_inner_error_;
#line 72 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_data_->_inner_error_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_data_->_tmp4_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_data_->_tmp4_ = _data_->e;
#line 78 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_data_->_tmp5_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 78 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		g_warning ("avatar-details-interface.vala:78: Error when calling prepare: %s\n", _data_->_tmp5_);
#line 72 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_g_error_free0 (_data_->e);
#line 380 "avatar-details-interface.c"
	}
	__finally0:
#line 72 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 72 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_g_object_unref0 (_data_->store);
#line 72 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 72 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		g_clear_error (&_data_->_inner_error_);
#line 72 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		return FALSE;
#line 393 "avatar-details-interface.c"
	}
#line 63 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_object_unref0 (_data_->store);
#line 63 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	if (_data_->_state_ == 0) {
#line 63 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 401 "avatar-details-interface.c"
	} else {
#line 63 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 405 "avatar-details-interface.c"
	}
#line 63 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	g_object_unref (_data_->_async_result);
#line 63 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	return FALSE;
#line 411 "avatar-details-interface.c"
}


static void __avatar_details_interface_tests_notify_avatar_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 95 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_avatar_details_interface_tests_notify_avatar_cb ((AvatarDetailsInterfaceTests*) self, _sender, pspec);
#line 418 "avatar-details-interface.c"
}


static void _avatar_details_interface_tests_individuals_changed_cb (AvatarDetailsInterfaceTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp30_ = NULL;
	gint _tmp31_ = 0;
	gint _tmp32_ = 0;
#line 82 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 82 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	g_return_if_fail (changes != NULL);
#line 85 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp0_ = changes;
#line 85 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 85 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	added = _tmp1_;
#line 86 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp2_ = changes;
#line 86 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 86 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	removed = _tmp3_;
#line 448 "avatar-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 88 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_tmp4_ = added;
#line 88 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 88 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_i_it = _tmp5_;
#line 88 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		while (TRUE) {
#line 461 "avatar-details-interface.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			gchar* full_name = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
#line 88 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_tmp6_ = _i_it;
#line 88 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 88 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			if (!_tmp7_) {
#line 88 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
				break;
#line 482 "avatar-details-interface.c"
			}
#line 88 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_tmp8_ = _i_it;
#line 88 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 88 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			i = (FolksIndividual*) _tmp9_;
#line 90 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_tmp10_ = i;
#line 90 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 92 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_tmp11_ = i;
#line 92 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_tmp12_ = folks_name_details_get_full_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 92 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_tmp13_ = _tmp12_;
#line 92 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_tmp14_ = g_strdup (_tmp13_);
#line 92 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			full_name = _tmp14_;
#line 93 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_tmp15_ = full_name;
#line 93 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			if (_tmp15_ != NULL) {
#line 508 "avatar-details-interface.c"
				FolksIndividual* _tmp16_ = NULL;
				FolksIndividual* _tmp17_ = NULL;
				GLoadableIcon* _tmp18_ = NULL;
				GLoadableIcon* _tmp19_ = NULL;
#line 95 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
				_tmp16_ = i;
#line 95 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
				g_signal_connect_object ((GObject*) _tmp16_, "notify::avatar", (GCallback) __avatar_details_interface_tests_notify_avatar_cb_g_object_notify, self, 0);
#line 96 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
				_tmp17_ = i;
#line 96 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
				_tmp18_ = folks_avatar_details_get_avatar ((FolksAvatarDetails*) _tmp17_);
#line 96 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
				_tmp19_ = _tmp18_;
#line 96 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
				if (_tmp19_ != NULL) {
#line 525 "avatar-details-interface.c"
					GFile* src_avatar = NULL;
					const gchar* _tmp20_ = NULL;
					GFile* _tmp21_ = NULL;
					GFileIcon* src_icon = NULL;
					GFile* _tmp22_ = NULL;
					GFileIcon* _tmp23_ = NULL;
					GFileIcon* _tmp24_ = NULL;
					FolksIndividual* _tmp25_ = NULL;
					GLoadableIcon* _tmp26_ = NULL;
					GLoadableIcon* _tmp27_ = NULL;
					gboolean _tmp28_ = FALSE;
					GMainLoop* _tmp29_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					_tmp20_ = self->priv->_avatar_uri;
#line 98 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					_tmp21_ = g_file_new_for_uri (_tmp20_);
#line 98 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					src_avatar = _tmp21_;
#line 99 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					_tmp22_ = src_avatar;
#line 99 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					_tmp23_ = (GFileIcon*) g_file_icon_new (_tmp22_);
#line 99 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					src_icon = _tmp23_;
#line 100 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					_tmp24_ = src_icon;
#line 100 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					_tmp25_ = i;
#line 100 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					_tmp26_ = folks_avatar_details_get_avatar ((FolksAvatarDetails*) _tmp25_);
#line 100 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					_tmp27_ = _tmp26_;
#line 100 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					_tmp28_ = g_icon_equal ((GIcon*) _tmp24_, (GIcon*) _tmp27_);
#line 100 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					self->priv->_avatars_are_equal = _tmp28_;
#line 101 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					_tmp29_ = self->priv->_main_loop;
#line 101 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					g_main_loop_quit (_tmp29_);
#line 96 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					_g_object_unref0 (src_icon);
#line 96 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
					_g_object_unref0 (src_avatar);
#line 570 "avatar-details-interface.c"
				}
			}
#line 88 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_g_free0 (full_name);
#line 88 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_g_object_unref0 (i);
#line 577 "avatar-details-interface.c"
		}
#line 88 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 581 "avatar-details-interface.c"
	}
#line 106 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp30_ = removed;
#line 106 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp31_ = gee_collection_get_size ((GeeCollection*) _tmp30_);
#line 106 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp32_ = _tmp31_;
#line 106 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_vala_assert (_tmp32_ == 1, "removed.size == 1");
#line 591 "avatar-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp33_ = NULL;
		GeeIterator* _tmp34_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_tmp33_ = removed;
#line 108 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_tmp34_ = gee_iterable_iterator ((GeeIterable*) _tmp33_);
#line 108 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_i_it = _tmp34_;
#line 108 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		while (TRUE) {
#line 604 "avatar-details-interface.c"
			GeeIterator* _tmp35_ = NULL;
			gboolean _tmp36_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp37_ = NULL;
			gpointer _tmp38_ = NULL;
			FolksIndividual* _tmp39_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_tmp35_ = _i_it;
#line 108 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_tmp36_ = gee_iterator_next (_tmp35_);
#line 108 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			if (!_tmp36_) {
#line 108 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
				break;
#line 619 "avatar-details-interface.c"
			}
#line 108 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_tmp37_ = _i_it;
#line 108 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_tmp38_ = gee_iterator_get (_tmp37_);
#line 108 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			i = (FolksIndividual*) _tmp38_;
#line 110 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_tmp39_ = i;
#line 110 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_vala_assert (_tmp39_ == NULL, "i == null");
#line 108 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
			_g_object_unref0 (i);
#line 633 "avatar-details-interface.c"
		}
#line 108 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 637 "avatar-details-interface.c"
	}
#line 82 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_object_unref0 (removed);
#line 82 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_object_unref0 (added);
#line 643 "avatar-details-interface.c"
}


static void _avatar_details_interface_tests_notify_avatar_cb (AvatarDetailsInterfaceTests* self, GObject* individual_obj, GParamSpec* ps) {
	FolksIndividual* individual = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	GFile* src_avatar = NULL;
	const gchar* _tmp2_ = NULL;
	GFile* _tmp3_ = NULL;
	GFileIcon* src_icon = NULL;
	GFileIcon* _tmp4_ = NULL;
	GLoadableIcon* _tmp5_ = NULL;
	GLoadableIcon* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	GMainLoop* _tmp8_ = NULL;
#line 114 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 114 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	g_return_if_fail (individual_obj != NULL);
#line 114 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	g_return_if_fail (ps != NULL);
#line 116 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp0_ = individual_obj;
#line 116 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 116 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	individual = _tmp1_;
#line 117 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp2_ = self->priv->_avatar_uri;
#line 117 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp3_ = g_file_new_for_uri (_tmp2_);
#line 117 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	src_avatar = _tmp3_;
#line 118 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp4_ = (GFileIcon*) g_file_icon_new (src_avatar);
#line 118 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	src_icon = _tmp4_;
#line 119 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp5_ = folks_avatar_details_get_avatar ((FolksAvatarDetails*) individual);
#line 119 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp6_ = _tmp5_;
#line 119 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp7_ = g_icon_equal ((GIcon*) src_icon, (GIcon*) _tmp6_);
#line 119 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	self->priv->_avatars_are_equal = _tmp7_;
#line 120 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp8_ = self->priv->_main_loop;
#line 120 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	g_main_loop_quit (_tmp8_);
#line 114 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_object_unref0 (src_icon);
#line 114 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_object_unref0 (src_avatar);
#line 114 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_object_unref0 (individual);
#line 700 "avatar-details-interface.c"
}


static void avatar_details_interface_tests_class_init (AvatarDetailsInterfaceTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	avatar_details_interface_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	g_type_class_add_private (klass, sizeof (AvatarDetailsInterfaceTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	G_OBJECT_CLASS (klass)->finalize = avatar_details_interface_tests_finalize;
#line 711 "avatar-details-interface.c"
}


static void avatar_details_interface_tests_instance_init (AvatarDetailsInterfaceTests * self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	self->priv = AVATAR_DETAILS_INTERFACE_TESTS_GET_PRIVATE (self);
#line 718 "avatar-details-interface.c"
}


static void avatar_details_interface_tests_finalize (GObject* obj) {
	AvatarDetailsInterfaceTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_AVATAR_DETAILS_INTERFACE_TESTS, AvatarDetailsInterfaceTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_free0 (self->priv->_avatar_uri);
#line 30 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 31 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 26 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	G_OBJECT_CLASS (avatar_details_interface_tests_parent_class)->finalize (obj);
#line 734 "avatar-details-interface.c"
}


GType avatar_details_interface_tests_get_type (void) {
	static volatile gsize avatar_details_interface_tests_type_id__volatile = 0;
	if (g_once_init_enter (&avatar_details_interface_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AvatarDetailsInterfaceTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) avatar_details_interface_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AvatarDetailsInterfaceTests), 0, (GInstanceInitFunc) avatar_details_interface_tests_instance_init, NULL };
		GType avatar_details_interface_tests_type_id;
		avatar_details_interface_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "AvatarDetailsInterfaceTests", &g_define_type_info, 0);
		g_once_init_leave (&avatar_details_interface_tests_type_id__volatile, avatar_details_interface_tests_type_id);
	}
	return avatar_details_interface_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	AvatarDetailsInterfaceTests* tests = NULL;
	AvatarDetailsInterfaceTests* _tmp0_ = NULL;
#line 126 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	g_test_init (&args_length1, &args, NULL);
#line 128 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_tmp0_ = avatar_details_interface_tests_new ();
#line 128 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	tests = _tmp0_;
#line 129 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 130 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	g_test_run ();
#line 131 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 133 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	result = 0;
#line 133 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	_g_object_unref0 (tests);
#line 133 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	return result;
#line 772 "avatar-details-interface.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 124 "/opt/gnome3/source/folks/tests/tracker/avatar-details-interface.vala"
	return _vala_main (argv, argc);
#line 782 "avatar-details-interface.c"
}



